@@ -2,6 +2,7 @@
 
 # Internal Libraries
 import re
+import sys
 import os.path
 import subprocess
 from platform import system
@@ -125,30 +126,65 @@ class FFmpeg():
 
             Log().error('ffmpeg must be installed and on PATH.')
 
-    def run(self, cmd):
-        cmd = [self.path, '-y'] + cmd
+    def print(self, message):
         if(self.debug):
-            cmd.extend(['-hide_banner'])
-            print(cmd)
-        else:
+            print('FFmpeg: {}'.format(message), file=sys.stderr)
+
+    def print_cmd(self, cmd):
+        if(self.debug):
+            print('FFmpeg run: {}\n'.format(' '.join(cmd)), file=sys.stderr)
+
+    def run(self, cmd):
+        cmd = [self.path, '-y', '-hide_banner'] + cmd
+        if(not self.debug):
             cmd.extend(['-nostats', '-loglevel', 'error'])
+        self.print_cmd(cmd)
         subprocess.call(cmd)
 
+    def run_check_errors(self, cmd, log, show_out=False):
+        process = self.Popen(cmd, stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+
+        stdout, stderr = process.communicate()
+        process.stdin.close()
+        output = stderr.decode()
+
+        import re
+        error_list = [
+            r"Unknown encoder '.*'",
+            r"-q:v qscale not available for encoder\. Use -b:v bitrate instead\.",
+            r'Specified sample rate .* is not supported',
+            r'Unable to parse option value ".*"',
+            r'Error setting option .* to value .*\.',
+            r"Undefined constant or missing '.*' in '.*'",
+        ]
+
+        if(self.debug):
+            print('stderr: {}'.format(stderr.decode()))
+            print('stdout: {}'.format(stdout.decode()))
+
+        for item in error_list:
+            check = re.search(item, output)
+            if(check):
+                log.error(check.group())
+
+        if(show_out and not self.debug):
+            print('stderr: {}'.format(stderr.decode()))
+            print('stdout: {}'.format(stdout.decode()))
+
     def file_info(self, path):
         return File(self, path)
 
     def Popen(self, cmd, stdin=None, stdout=subprocess.PIPE, stderr=None):
         cmd = [self.path] + cmd
+        self.print_cmd(cmd)
         return subprocess.Popen(cmd, stdin=stdin, stdout=stdout, stderr=stderr)
 
     def pipe(self, cmd):
         # type: (list[str]) -> str
         cmd = [self.path, '-y'] + cmd
 
-        if(self.debug):
-            print(cmd)
+        self.print_cmd(cmd)
         output = get_stdout(cmd)
-        if(self.debug):
-            print(output)
-
+        self.print(output)
         return output
