@@ -4,30 +4,32 @@
 import os.path
 import subprocess
 
+# From: github.com/PyAV-Org/PyAV/blob/main/av/video/frame.pyx
+allowed_pix_fmt = {'yuv420p', 'yuvj420p', 'rgb24', 'bgr24', 'argb', 'rgba',
+    'abgr', 'bgra', 'gray', 'gray8', 'rgb8', 'bgr8', 'pal8'}
+
 def pix_fmt_allowed(pix_fmt):
     # type: (str) -> bool
+    return pix_fmt in allowed_pix_fmt
 
-    # From: github.com/PyAV-Org/PyAV/blob/main/av/video/frame.pyx
-    allowed_formats = ['yuv420p', 'yuvj420p', 'rgb24', 'bgr24', 'argb', 'rgba',
-        'abgr', 'bgra', 'gray', 'gray8', 'rgb8', 'bgr8', 'pal8']
+class Wrapper:
+    """
+    Wrapper which only exposes the `read` method to avoid PyAV
+    trying to use `seek`.
+    From: github.com/PyAV-Org/PyAV/issues/578#issuecomment-621362337
+    """
 
-    return pix_fmt in allowed_formats
+    name = "<wrapped>"
+
+    def __init__(self, fh):
+        self._fh = fh
+
+    def read(self, buf_size):
+        return self._fh.read(buf_size)
 
 
-def scale_to_sped(ffmpeg, spedup, scale, inp, args, temp):
-    cmd = ['-i', scale, spedup]
-    check_errors = ffmpeg.pipe(cmd)
-
-    if('Error' in check_errors or 'failed' in check_errors):
-        cmd = ['-i', scale]
-        if('-allow_sw 1' in check_errors):
-            cmd.extend(['-allow_sw', '1'])
-
-        cmd = properties(cmd, args, inp)
-        cmd.append(spedup)
-        ffmpeg.run(cmd)
-
-def render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr, progress, effects, temp, log):
+def render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr, progress, effects, rules,
+    temp, log):
     try:
         import av
     except ImportError:
@@ -39,28 +41,9 @@ def render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr, progress, effects
     input_ = av.open(inp.path)
     pix_fmt = input_.streams.video[0].pix_fmt
 
-    def throw_pix_fmt(inp, pix_fmt, log):
-        log.error('''pix_fmt {} is not supported.\n
-Convert your video to a supported pix_fmt. The following command might work for you:
-  ffmpeg -i "{}" -pix_fmt yuv420p converted{}
-'''.format(pix_fmt, inp.path, '' if inp.ext is None else inp.ext))
+    apply_video = True
 
     if(has_vfr):
-        class Wrapper:
-            """
-            Wrapper which only exposes the `read` method to avoid PyAV
-            trying to use `seek`.
-            From: github.com/PyAV-Org/PyAV/issues/578#issuecomment-621362337
-            """
-
-            name = "<wrapped>"
-
-            def __init__(self, fh):
-                self._fh = fh
-
-            def read(self, buf_size):
-                return self._fh.read(buf_size)
-
         # Create a cfr stream on stdout.
         cmd = ['-i', inp.path, '-map', '0:v:0', '-vf', 'fps=fps={}'.format(fps), '-r',
             str(fps), '-vsync', '1', '-f', 'matroska']
@@ -73,9 +56,16 @@ Convert your video to a supported pix_fmt. The following command might work for
         wrapper = Wrapper(ffmpeg.Popen(cmd).stdout)
         input_ = av.open(wrapper, 'r')
     elif(not pix_fmt_allowed(pix_fmt)):
-        throw_pix_fmt(inp, pix_fmt, log)
+        pix_fmt = 'yuv420p'
+        cmd = ['-i', inp.path, '-map', '0:v:0', '-f', 'matroska', '-pix_fmt', pix_fmt,
+            '-vcodec', 'rawvideo', 'pipe:1']
+        wrapper = Wrapper(ffmpeg.Popen(cmd).stdout)
+        input_ = av.open(wrapper, 'r')
+    else:
+        apply_video = inp.ext != '.mp4'
 
     log.debug('pix_fmt: {}'.format(pix_fmt))
+    log.debug('apply video quality settings now: {}'.format(not apply_video))
 
     inputVideoStream = input_.streams.video[0]
     inputVideoStream.thread_type = 'AUTO'
@@ -97,15 +87,29 @@ Convert your video to a supported pix_fmt. The following command might work for
 
     cmd = ['-hide_banner', '-y', '-f', 'rawvideo', '-c:v', 'rawvideo',
         '-pix_fmt', pix_fmt, '-s', '{}*{}'.format(width, height), '-framerate', str(fps),
-        '-i', '-', '-pix_fmt', pix_fmt, '-c:v', 'mpeg4', '-qscale:v', '1']
+        '-i', '-', '-pix_fmt', pix_fmt]
 
     if(args.scale != 1):
-        cmd.extend(['-vf', 'scale=iw*{}:ih*{}'.format(args.scale, args.scale)])
+        apply_video = False
+
+    from auto_editor.utils.encoder import encoders
+    from auto_editor.utils.video import get_vcodec, video_quality
+
+    my_codec = get_vcodec(args, inp, rules)
+
+    if(my_codec in encoders):
+        if(encoders[my_codec]['pix_fmt'].isdisjoint(allowed_pix_fmt)):
+            apply_video = True
+
+    if(apply_video):
+        cmd.extend(['-c:v', 'mpeg4', '-qscale:v', '1'])
+    else:
+        cmd = video_quality(cmd, args, inp, rules)
 
     cmd.append(spedup)
 
     process2 = ffmpeg.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.DEVNULL,
-        stderr=None if args.show_ffmpeg_debug else subprocess.DEVNULL)
+        stderr=subprocess.DEVNULL)
 
     inputEquavalent = 0.0
     outputEquavalent = 0
@@ -136,9 +140,25 @@ Convert your video to a supported pix_fmt. The following command might work for
         process2.stdin.close()
         process2.wait()
     except BrokenPipeError:
-        log.print(cmd)
-        process2 = ffmpeg.Popen(cmd, stdin=subprocess.PIPE)
-        log.error('Broken Pipe Error!')
+        progress.end()
+        ffmpeg.run_check_errors(cmd, log, True)
+        log.error('FFmpeg Error!')
 
-    return spedup
+    # Unfortunately, scaling has to be a concrete step.
+    if(args.scale != 1):
+        sped_input = os.path.join(temp, 'spedup.mp4')
+        spedup = os.path.join(temp, 'scale.mp4')
+        cmd = ['-i', sped_input, '-vf', 'scale=iw*{s}:ih*{s}'.format(s=args.scale),
+            spedup]
+
+        check_errors = ffmpeg.pipe(cmd)
+        if('Error' in check_errors or 'failed' in check_errors):
+            if('-allow_sw 1' in check_errors):
+                # Add "-allow_sw 1" to command.
+                cmd.insert(-1, '1')
+                cmd.insert(-1, '-allow_sw')
+            # Run again to show errors even if it might not work.
+            ffmpeg.run(cmd)
+
+    return spedup, apply_video
 
