@@ -118,7 +118,7 @@ def run_program(cmd):
         raise Exception('{}\n{}\n'.format(stdout, stderr))
 
 
-def checkForError(cmd, match=None):
+def check_for_error(cmd, match=None):
     returncode, stdout, stderr = pipe_to_console(getRunner() + cmd)
     if(returncode > 0):
         if('Error!' in stderr):
@@ -129,7 +129,10 @@ def checkForError(cmd, match=None):
     else:
         raise Exception('Program should not respond with a code 0.')
 
-def fullInspect(path, *args):
+def inspect(path, *args):
+    if(not os.path.exists(path)):
+        raise Exception(f"Path '{path}' does not exist.")
+
     for item in args:
         func = item[0]
         expectedOutput = item[1]
@@ -314,15 +317,16 @@ def main(sys_args=None):
     tester.run_test('level_tests', level_tests)
 
     def example_tests():
-        run_program(['example.mp4'])
-        fullInspect(
+        run_program(['example.mp4', '--has_vfr', 'no'])
+        inspect(
             'example_ALTERED.mp4',
             [ffprobe.getFrameRate, 30.0],
             [ffprobe.getResolution, '1280x720'],
+            [ffprobe.getVideoCodec, 'h264'],
             [ffprobe.getSampleRate, '48000'],
         )
-        run_program(['example.mp4', '--video_codec', 'uncompressed'])
-        fullInspect(
+        run_program(['example.mp4', '--video_codec', 'uncompressed', '--has_vfr', 'no'])
+        inspect(
             'example_ALTERED.mp4',
             [ffprobe.getFrameRate, 30.0],
             [ffprobe.getResolution, '1280x720'],
@@ -338,8 +342,8 @@ def main(sys_args=None):
 
     # Issue #172
     def bitrate_test():
-        run_program(['example.mp4', '--audio_bitrate', '50k'])
-        fullInspect(
+        run_program(['example.mp4', '--audio_bitrate', '50k', '--has_vfr', 'no'])
+        inspect(
             'example_ALTERED.mp4',
             [ffprobe.AudioBitRate, '50k'],
         )
@@ -348,10 +352,10 @@ def main(sys_args=None):
     # Issue #184
     def unit_tests():
         run_program(['example.mp4', '--mark_as_loud', '20s,22sec', '25secs,26.5seconds'])
-        run_program(['example.mp4', '--sample_rate', '44100'])
-        run_program(['example.mp4', '--sample_rate', '44100 Hz'])
-        run_program(['example.mp4', '--sample_rate', '44.1 kHz'])
-        run_program(['example.mp4', '--silent_threshold', '4%'])
+        run_program(['example.mp4', '--sample_rate', '44100', '--has_vfr', 'no'])
+        run_program(['example.mp4', '--sample_rate', '44100 Hz', '--has_vfr', 'no'])
+        run_program(['example.mp4', '--sample_rate', '44.1 kHz', '--has_vfr', 'no'])
+        run_program(['example.mp4', '--silent_threshold', '4%', '--has_vfr', 'no'])
     tester.run_test('unit_tests', unit_tests,
         description='''
         Make sure all units are working appropriately. That includes:
@@ -372,13 +376,17 @@ def main(sys_args=None):
 
     def cut_out_test():
         run_program(['example.mp4', '--edit', 'none', '--video_speed', '2',
-            '--silent_speed', '3', '--cut_out', '2secs,10secs'])
+            '--silent_speed', '3', '--cut_out', '2secs,10secs', '--has_vfr', 'no'])
         run_program(['example.mp4', '--edit', 'all', '--video_speed', '2',
-            '--add_in', '2secs,10secs'])
+            '--add_in', '2secs,10secs', '--has_vfr', 'no'])
     tester.run_test('cut_out_test', cut_out_test)
 
     def gif_test():
         run_program(['resources/man_on_green_screen.gif', '--edit', 'none'])
+        inspect(
+            'resources/man_on_green_screen_ALTERED.gif',
+            [ffprobe.getVideoCodec, 'gif'],
+        )
     tester.run_test('gif_test', gif_test, description='''
         Feed auto-editor a gif file and make sure it can spit out a correctly formated
         gif. No editing is requested.
@@ -394,22 +402,35 @@ def main(sys_args=None):
         run_program(['example.mp4', '-m', '0.4 seconds'])
     tester.run_test('margin_tests', margin_tests)
 
-    def extension_tests():
+    def input_extension():
+        # Input file must have an extension. Throw error if none is given.
         shutil.copy('example.mp4', 'example')
-        checkForError(['example', '--no_open'], 'must have an extension.')
+        check_for_error(['example', '--no_open'], 'must have an extension.')
         os.remove('example')
 
-        run_program(['example.mp4', '-o', 'example.mkv'])
-        os.remove('example.mkv')
+    tester.run_test('input_extension', input_extension)
 
-        run_program(['resources/test.mkv', '-o', 'test.mp4'])
-        os.remove('test.mp4')
+    def output_extension():
+        # Add input extension to output name if no output extension is given.
+        run_program(['example.mp4', '--has_vfr', 'no', '-o', 'out'])
+        inspect(
+            'out.mp4',
+            [ffprobe.getVideoCodec, 'h264']
+        )
+        os.remove('out.mp4')
 
-    tester.run_test('extension_tests', extension_tests)
+        run_program(['resources/test.mkv', '--has_vfr', 'no', '-o', 'out'])
+        inspect(
+            'out.mkv',
+            [ffprobe.getVideoCodec, 'h264']
+        )
+        os.remove('out.mkv')
+
+    tester.run_test('output_extension', output_extension)
 
     def progress_ops_test():
-        run_program(['example.mp4', 'progressOps', '--machine_readable_progress'])
-        run_program(['example.mp4', 'progressOps', '--no_progress'])
+        run_program(['example.mp4', '--has_vfr', 'no', 'progressOps', '--machine_readable_progress'])
+        run_program(['example.mp4', '--has_vfr', 'no', 'progressOps', '--no_progress'])
     tester.run_test('progress_ops_test', progress_ops_test)
 
     def silent_threshold():
@@ -427,24 +448,17 @@ def main(sys_args=None):
         run_program(['example.json'])
     tester.run_test('json_tests', json_tests)
 
-    def speed_tests():
-        run_program(['example.mp4', '-s', '2', '-mcut', '10'])
-        run_program(['example.mp4', '-v', '2', '-mclip', '4'])
-        run_program(['example.mp4', '--sounded_speed', '0.5'])
-        run_program(['example.mp4', '--silent_speed', '0.5'])
-    tester.run_test('speed_tests', speed_tests)
-
     def scale_tests():
-        run_program(['example.mp4', '--scale', '1.5'])
-        fullInspect(
+        run_program(['example.mp4', '--scale', '1.5', '--has_vfr', 'no'])
+        inspect(
             'example_ALTERED.mp4',
             [ffprobe.getFrameRate, 30.0],
             [ffprobe.getResolution, '1920x1080'],
             [ffprobe.getSampleRate, '48000'],
         )
 
-        run_program(['example.mp4', '--scale', '0.2'])
-        fullInspect(
+        run_program(['example.mp4', '--scale', '0.2', '--has_vfr', 'no'])
+        inspect(
             'example_ALTERED.mp4',
             [ffprobe.getFrameRate, 30.0],
             [ffprobe.getResolution, '256x144'],
@@ -453,15 +467,15 @@ def main(sys_args=None):
     tester.run_test('scale_tests', scale_tests)
 
     def various_errors_test():
-        checkForError(['example.mp4', '--zoom', '0', '--cut_out', '60,end'])
-        checkForError(['example.mp4', '--zoom', '0,60', '--cut_out', '60,end'])
-        checkForError(['example.mp4', '--rectangle', '0,60', '--cut_out', '60,end'])
+        check_for_error(['example.mp4', '--zoom', '0', '--cut_out', '60,end'])
+        check_for_error(['example.mp4', '--zoom', '0,60', '--cut_out', '60,end'])
+        check_for_error(['example.mp4', '--rectangle', '0,60', '--cut_out', '60,end'])
     tester.run_test('various_errors_test', various_errors_test)
 
     def effect_tests():
         run_program(['create', 'test', '--width', '640', '--height', '360', '-o',
             'testsrc.mp4'])
-        fullInspect(
+        inspect(
             'testsrc.mp4',
             [ffprobe.getFrameRate, 30.0],
             [ffprobe.getResolution, '640x360'],
@@ -474,7 +488,7 @@ def main(sys_args=None):
 
         run_program(['testsrc.mp4', '--mark_as_loud', 'start,end', '--zoom',
             'start,end,1,0.5,centerX,centerY,linear', '--scale', '0.5'])
-        fullInspect(
+        inspect(
             'testsrc_ALTERED.mp4',
             [ffprobe.getFrameRate, 30.0],
             [ffprobe.getResolution, '320x180'],
