@@ -12,12 +12,51 @@ def fset(cmd, option, value):
     return cmd + [option] + [value]
 
 
-def mux_quality_media(ffmpeg, spedup, rules, write_file, container, args, inp, temp, log):
+def get_vcodec(args, inp, rules):
+    vcodec = args.video_codec
+    if(vcodec == 'auto'):
+        vcodec = inp.video_streams[0]['codec']
+
+        if((rules['vstrict'] and vcodec not in rules['vcodecs'])
+            or (vcodec in rules['disallow_v'])):
+            return rules['vcodecs'][0]
+
+    if(vcodec == 'copy'):
+        return inp.video_streams[0]['codec']
+
+    if(vcodec == 'uncompressed'):
+        return 'mpeg4'
+    return vcodec
+
+
+def video_quality(cmd, args, inp, rules):
+    cmd = fset(cmd, '-crf', args.constant_rate_factor)
+    cmd = fset(cmd, '-b:v', args.video_bitrate)
+    cmd = fset(cmd, '-tune', args.tune)
+    cmd = fset(cmd, '-preset', args.preset)
+
+    qscale = args.video_quality_scale
+
+    if(args.video_codec == 'uncompressed' and fnone(qscale)):
+        qscale = '1'
+
+    vcodec = get_vcodec(args, inp, rules)
+
+    cmd.extend(['-c:v', vcodec])
+
+    cmd = fset(cmd, '-qscale:v', qscale)
+
+    cmd.extend(['-movflags', 'faststart'])
+    return cmd
+
+
+def mux_quality_media(ffmpeg, spedup, rules, write_file, container, apply_video,
+    args, inp, temp, log):
     s_tracks = 0 if not rules['allow_subtitle'] else len(inp.subtitle_streams)
     a_tracks = 0 if not rules['allow_audio'] else len(inp.audio_streams)
     v_tracks = 0 if not rules['allow_video'] else len(inp.video_streams)
 
-    cmd = []
+    cmd = ['-hide_banner', '-y']
     if(spedup is not None):
         cmd.extend(['-i', spedup])
 
@@ -44,33 +83,17 @@ def mux_quality_media(ffmpeg, spedup, rules, write_file, container, args, inp, t
             new_path = os.path.join(temp, 'new{}s.{}'.format(s, sub['ext']))
             cmd.extend(['-i', new_path])
 
-    total_streams = v_tracks + s_tracks + (a_tracks if args.keep_tracks_seperate else min(a_tracks, 1))
+    # copying png streams isn't supported yet.
+    total_streams = min(v_tracks, 1) + s_tracks + (a_tracks if args.keep_tracks_seperate else min(a_tracks, 1))
 
     for i in range(total_streams):
         cmd.extend(['-map', '{}:0'.format(i)])
 
     if(v_tracks > 0):
-        cmd = fset(cmd, '-crf', args.constant_rate_factor)
-        cmd = fset(cmd, '-b:v', args.video_bitrate)
-        cmd = fset(cmd, '-tune', args.tune)
-        cmd = fset(cmd, '-preset', args.preset)
-
-        if(fnone(args.video_codec) or args.video_codec == 'uncompressed'):
-            if(rules['vcodecs'] is None):
-                cmd.extend(['-c:v', 'copy'])
-            else:
-                cmd.extend(['-c:v', rules['vcodecs'][0]])
+        if(apply_video):
+            cmd = video_quality(cmd, args, inp, rules)
         else:
-            vcodec = args.video_codec
-            if(vcodec == 'copy'):
-                vcodec = inp.video_streams[0].codec
-            if(vcodec == 'uncompressed'):
-                vcodec = 'copy'
-
-            # Rules checking is in edit.py
-            cmd.extend(['-c:v', vcodec])
-
-        cmd.extend(['-movflags', 'faststart'])
+            cmd.extend(['-c:v', 'copy'])
 
     if(s_tracks > 0):
         scodec = inp.subtitle_streams[0]['codec']
@@ -92,4 +115,4 @@ def mux_quality_media(ffmpeg, spedup, rules, write_file, container, args, inp, t
             cmd.extend(['-ar', str(args.sample_rate)])
 
     cmd.extend(['-strict', '-2', write_file]) # Allow experimental codecs.
-    ffmpeg.run(cmd)
+    ffmpeg.run_check_errors(cmd, log)
